@@ -63,7 +63,7 @@ class RedizConventions(MicroConventions):
         self.DELAYS = delays or [1, 5]
         self.ZDELAYS = [self.DELAYS[0],self.DELAYS[-1]]
         self.CONFIRMS_MAX = 5  # Maximum number of confirmations when using mset()
-        self.NOISE = 0.1 / self.NUM_PREDICTIONS  # Tie-breaking / smoothing noise added to predictions
+        self.NOISE = 0.1 / self.num_predictions  # Tie-breaking / smoothing noise added to predictions
         self.NUM_WINNERS = 10   # Maximum number of winning tickets
 
         # Implementation details: private reserved redis keys and prefixes.
@@ -187,6 +187,18 @@ class RedizConventions(MicroConventions):
         delays = [d for _, d in names_delays]
         return names, delays
 
+    def overall_monthly_sponsored_leaderboard_name(self, sponsor):
+        return self.custom_leaderboard_name(sponsor=sponsor, name=None)
+
+    def regular_monthly_sponsored_leaderboard_name(self,sponsor):
+        return self.custom_leaderboard_name(sponsor=sponsor, name='name.json')
+
+    def bivariate_monthly_sponsored_leaderboard_name(self,sponsor):
+        return self.custom_leaderboard_name(sponsor=sponsor, name='z2~whatever.json')
+
+    def trivariate_monthly_sponsored_leaderboard_name(self, sponsor):
+        return self.custom_leaderboard_name(sponsor=sponsor, name='z3~whatever.json')
+
     def custom_leaderboard_name(self, sponsor, name=None, dt=None):
         """ Names for leaderboards with a given sponsor
         :param sponsor:  str
